<?php

namespace App\Helpers;

use App\Models\Admin as AdminModel;
use App\Models\Product;
use App\Models\AdminPermission;
use App\Models\AdminSetting;
use Cookie;
use Session;

class Admin
{
    public static function checkLogin()
    {
        $session = self::getSession();
        if (!empty($session['user_id'])) {
            return 'success';
        }
        return 'error';
    }
    public static function checkAdminLogin()
    {
        return self::authenticateUser('1');
    }
    public static function setSession($userId = '', $role = '')
    {
        self::destroySession();
        Session::put('user_id', $userId);
        Session::put('user_role', $role);
        Session::save();

        return 'success';
    }
    public static function getSession()
    {
        return [
            'user_id' => Session::get('user_id'),
            'user_role' => Session::get('user_role'),
        ];
    }
    public static function flashSessionMessage($status, $message)
    {
        return Session::flash('flash-message', ['status' => $status, 'msg' => $message]);
    }
    public static function destroySession()
    {
        Session::remove('user_id');
        Session::remove('user_role');

        return 'success';
    }
    public static function currentUser()
    {
        return AdminModel::where('id', self::getSession()['user_id'])->first();
    }
    public static function setRememberMeCookie($email, $password)
    {
        Cookie::queue('remember_email', $email);
        Cookie::queue('remember_password', $password);
    }
    public static function getRememberMeCookie()
    {
        return array('email' => Cookie::get('remember_email'), 'password' => Cookie::get('remember_password'));
    }
    public static function destroyRememberMeCookie()
    {
        Cookie::queue(Cookie::forget('remember_email'));
        Cookie::queue(Cookie::forget('remember_password'));

        return 'success';
    }
    public static function authenticateUser($role)
    {
        $currentUser = self::currentUser();
        switch ($currentUser) {
            case isset($currentUser) && empty($currentUser):
                return 'error_account_deleted';
                break;
            default:
                return 'success';
                break;
        }
    }
    public static function isCurrentRoute($routes = [], $activeClass = 'active')
    {
        if (in_array(\Route::currentRouteName(), $routes)) {
            return $activeClass;
        }

        return '';
    }
    public static function removeCityFromAttachedProducts($cityId)
    {
        $attachedProduct = Product::whereRaw('FIND_IN_SET(' . $cityId . ',cities)')->get(['id', 'cities']);
        if ($attachedProduct->count() > 0) {
            foreach ($attachedProduct as $key => $product) {
                $cities = explode(',', $product->cities);
                $foundAtIndex = array_search($cityId, $cities);
                unset($cities[$foundAtIndex]);
                $product->cities = !empty($cities) ? implode(',', $cities) : null;
                $product->save();
            }
        }
    }
    public static function getWeekStartEndDateByDate($date)
    {
        $ts = strtotime($date);
        $start = (date('w', $ts) == 1) ? $ts : strtotime('last monday', $ts);

        return array(
            'start_date' => date('Y-m-d', $start),
            'end_date' => date('Y-m-d', strtotime('next sunday', $start)),
        );
    }
    public static function getLastWeekStartEndDateByDate()
    {
        $lastWeek = strtotime("-1 week +1 day");
        $startDate = strtotime("last monday midnight", $lastWeek);
        $endDate = strtotime("next sunday", $startDate);
        $startDate = date("Y-m-d", $startDate);
        $endDate = date("Y-m-d", $endDate);

        return array(
            'start_date' => $startDate,
            'end_date' => $endDate,
        );
    }
    public static function getStartEndDateOfMonthByDate($date = '')
    {
        if (empty($date)) {
            $date = date('Y-m-d');
        }

        return array(
            'start_date' => date('Y-m-01', strtotime($date)),
            'end_date' => date('Y-m-t', strtotime($date)),
        );
    }
    public static function getStartEndDateOfLastMonth()
    {
        return array(
            'start_date' => date('Y-m-01', strtotime('last month')),
            'end_date' => date('Y-m-t', strtotime('last month')),
        );
    }
    public static function checkPermission($user_id,$controller,$action)
    {
        $check = 0;
        if(Session::get('user_role') != 1)
      
        {
          $checkpermission = AdminPermission::select('admin_permissions.permission_id')
          ->join('admin_role_sub_permissions','admin_role_sub_permissions.id','=','admin_permissions.permission_id')
          ->join('admin_role_permissions','admin_role_permissions.id','=','admin_role_sub_permissions.parent_admin_role_permission_id')
          ->where('admin_permissions.admin_id',$user_id)
          ->where('admin_role_permissions.name',$controller)
          ->where('admin_role_sub_permissions.name',$action)
          ->get();
         
          if(count($checkpermission) > 0)
          {
              $check=1;
          }else{
            $check = 0;
          }
        }else {
          $check=1;
        }
        return $check;
    }
    public static function tapsettings()
    {
        //$session = self::getSession();
       // if (!empty($session['user_id'])) {
            return AdminSetting::select('*')->where('id','1')->first();
        //}
        //return 'error';
    }
}
