<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\FAQ;
use DataTables;
use App\Helpers\Admin;
use Session;

class FAQController extends Controller
{
     /**
     * FAQ List
     */
    public function index(Request $request)
    {
        $permission = Admin::checkPermission(Session::get('user_id'),'FAQ','View');
    
      if($permission == 0){
        
        return redirect()->route('admin.dashboard')->with('message','You dont have permission to do this action')->send();


      }else{
        if ($request->ajax()) {
            $data = FAQ::select('*');
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('question', function($row){
                        return $row->question;
                    })
                    ->addColumn('answer', function($row){
                        return strip_tags($row->answer);
                    })
                    ->addColumn('created_at', function($row){
                        return date('d-m-Y', strtotime($row->created_at));
                    })
                    ->addColumn('updated_at', function($row){
                        return date('d-m-Y', strtotime($row->updated_at));
                    })
                    ->addColumn('status', function($row){
                        return $row->status;
                    })
                    ->addColumn('action', function($row){
                        $urlpath = url('admin/faq');
                         $delete = Admin::checkPermission(Session::get('user_id'),'FAQ','Delete');
                         $update = Admin::checkPermission(Session::get('user_id'),'FAQ','Update');
                        $btn = '';
                        if($update == 1){
                            $btn = '<a href="javascript:void(0);" onClick="changeStatus('.$row->id.')" class=" dropdown-item"><i class="zmdi zmdi-account zmdi-hc-fw text-secondary"></i>Active/Inactive</a>  <a href="'.$urlpath.'/edit/'. $row->id .'" class="dropdown-item"><i class="zmdi zmdi-edit zmdi-hc-fw text-secondary"></i>Edit</a>';
                        }
                        if($delete == 1){
                            $btn .= '<a href="javascript:void(0);" onClick="deleteFunc('.$row->id.')" class="dropdown-item"><i class="zmdi zmdi-delete zmdi-hc-fw text-secondary"></i>Delete</a>';
                        }
                        return '<div class="btn-group dot-view-acation"><a href="#" data-toggle="dropdown" class="btn btn-default btn-sm btn-icon-only transparent" title=""><i class="zmdi zmdi-more"></i></a>
                            <div class="dropdown-menu dropdown-icon-menu dropdown-menu-right">'.$btn.'</div></div>';
                       
                    })
                    ->rawColumns(['question','answer','created_at','updated_at','action','status'])
                    ->make(true);
        }
        return view('admin.faqs.list');
    }
    }

    public function add(){
        return view('admin.faqs.add');
    }

    public function store(Request $request) {
      $validated = $request->validate([
        'question' => 'required',
        'answer' => 'required',
      ]);
        $faq = new FAQ();
        $faq->question = $request->question;
        $faq->answer = $request->answer;
        $faq->status = $request->status;
        $faq->save();
        // return redirect()->back()->with('message', 'Category updated successfully!');
        return redirect()->route('admin.faq.list')->with('message', 'FAQ record added successfully!');
    }

    public function edit($id) {
        $faq = FAQ::find($id)->toArray();
        return view('admin.faqs.edit')->with('faq', $faq);
    }

    public function update(Request $request){
      $validated = $request->validate([
        'question' => 'required',
        'answer' => 'required',
      ]);
        $faq = FAQ::find($request->faq_id);
        $faq->question = $request->question;
        $faq->answer = $request->answer;
        $faq->status = $request->status;
        $faq->update();
        // return redirect()->back()->with('message', 'Category updated successfully!');
        return redirect()->route('admin.faq.list')->with('message', 'FAQ record updated successfully!');
    }

    public function delete($id){
        FAQ::find($id)->delete();
        return response()->json([
            'success' => 'Record has been deleted successfully!'
        ]);
        // return redirect()->route('admin.category.list')->with('message', 'Category record delete successfully!');
    }

    public function changeStatus($id){
        $faq = FAQ::find($id);
        if($faq->status == '1'){
            $faq->status = "0";
        } else {
            $faq->status = "1";
        }
        $faq->update();
        return response()->json([
            'success' => 'Record status has been changed successfully!'
        ]);
    }
}
