<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Bannerdeals;
use App\Models\Rolepermission;
use App\Models\Language;
use DataTables;
use App\Models\Orders;
use App\Models\Orderdetail;
use App\Models\Fooditems;
use App\Helpers\s3upload;
use App\Helpers\NotificationHelper;
use App\Helpers\TapPayment;
use App\Helpers\Admin;
use Hash;
use Illuminate\Support\Facades\Storage;
use Session;
use App\Helpers\RolepermissionHelper;
use App\Helpers\RestaurantHelper;

class OrderController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
  public function __construct() {
      $permission = Admin::checkPermission(Session::get('user_id'),'Orders','View');
    
      if($permission == 0){
    
         return redirect()->route('admin.dashboard')->with('message','You dont have permission to do this action')->send();

      }
   }
    public function index(Request $request) {
            
        $total_order = Orders::where('payment_method','!=','p')->count();
        
        $count = Orders::select('orders.*','users.restaurant_name')->where('payment_method','!=','p')->with('orderdetails')
                ->leftjoin('users','users.id','=','orders.restaurant_id')
                ->count();
      
        $past_order = Orders::select('orders.*','users.restaurant_name')->whereIN('orders.order_status',array('co','cn'))->where('payment_method','!=','p')->with('orderdetails')->orderBy('id','DESC')
                ->leftjoin('users','users.id','=','orders.restaurant_id')
                ->get()->count();

      $new_order = Orders::select('orders.*','users.restaurant_name')->where('payment_method','!=','p')->with('orderdetails')->orderBy('id','DESC')
      ->whereIN('orders.order_status', array('p','a','c','s','pe'))
                ->leftjoin('users','users.id','=','orders.restaurant_id')
                ->get()->count();
        
        if ($request->ajax()) {
                $data = Orders::select('orders.*','users.restaurant_name')->where('payment_method','!=','p')->with('orderdetails')->orderBy('id','DESC')
                ->whereIN('orders.order_status', array('p','a','c','s','pe'))
                ->leftjoin('users','users.id','=','orders.restaurant_id')
                ->get();

            return Datatables::of($data)
                    ->addIndexColumn()
                     ->addColumn('id', function($row){
                        return $row['id'];
                    })
                  ->addColumn('display_order_id', function($row){
                        return 'order'.$row['display_order_id'];
                    })
                    ->addColumn('order_date', function($row){
                        return date('d-m-Y', strtotime($row->created_at));
                    })
                    ->addColumn('order_time', function($row){
                        return date('h:i A', strtotime($row->created_at));
                    })
                    ->addColumn('customer_name', function($row){
                        if($row->customer_name != ''){
                            return $row->customer_name;
                        }else{
                            return 'guest';
                        }
                    })

                    ->addColumn('customer_mobile_no', function($row){
                        return $row['customer_mobile_no'];
                    })
                    ->addColumn('restaurant_name', function($row){
                        return $row['restaurant_name'];
                    })
                     ->addColumn('table_no', function($row){
                        return $row['table_no'];
                    })

                     
                 ->addColumn('fooditems', function($row){
                    if(!empty($row['orderdetails'])){
                        $foodname = array();
                        foreach($row['orderdetails'] as $fooditems){
                            $foodname[] = $fooditems['food_name'];
                        }
                        return implode(',',$foodname);
                        
                    }else{
                        return '';
                    }

                    })
                      ->addColumn('quantity', function($row){
                    if(!empty($row['orderdetails'])){
                        $quantity = 0;
                        foreach($row['orderdetails'] as $fooditems){
                            $quantity = $quantity + $fooditems['quantity'];
                        }
                        return $quantity;
                        
                    }else{
                        return '';
                    }
                    })
                       ->addColumn('total_amount_pay', function($row){
                        return number_format($row['total_amount_pay'],2).' '.config('constant.CURRENCY');
                    })
                    ->addColumn('payment_method', function($row){
                        if($row->payment_method == 'ca'){
                            return 'Card';
                        }else{
                            return 'Cash';
                        }
                    })
                        ->addColumn('order_status_action', function($row){
                            if($row['order_status'] == 'a')
                                    return 'Accepted';
                            elseif($row['order_status'] == 'p')
                                    return 'Preparing';
                            elseif($row['order_status'] == 'c')
                                    return 'Coming';
                            elseif($row['order_status'] == 's')
                                    return 'Served';
                            elseif($row['order_status'] == 'co')
                                    return 'Completed';
                            elseif($row['order_status'] == 'cn')
                                    return 'Cancelled';
                            else
                                    return 'Pending';                                       
                        })
                      
                       ->addColumn('order_status', function($row){
                          return $row['order_status'];  
                     })
                    // ->addColumn('change_status', function($row){

                    //     return '<select id="order_status_change" data-id="'. $row->id .'">
                    //     <option value="">Change Status</option>
                    //     <option value="a">Accepted</option>
                    //     <option value="p" if($row["order_status"] == "p"){
                    //                  echo "selected"; }>Preparing</option>
                    //     <option value="c" if($row["order_status"] == "c"){
                    //                  echo "selected"; }>Coming</option>
                    //     <option value="s" if($row["order_status"] == "s"){
                    //                  echo "selected"; }>Served</option>
                    //     <option value="co" if($row["order_status"] == "co"){
                    //                  echo "selected"; }>Completed</option>
                    //     <option value="cn" if($row["order_status"] == "cn"){
                    //                  echo "selected"; }>Cancelled</option>
                    //     </select>';
                    // }) 
                    ->addColumn('action', function($row){
                        $urlpath = url('admin/orders');
                        $btn = '';
                       
                        $btn .= '<a href="'.$urlpath.'/view/'. $row->id .'" class="view"><i class="material-icons">visibility</i></a>';
                         if($row->order_status == 'pe'){
                           $btn .= '<a href="javascript:void(0);" onClick="cancelorder('.$row->id.')" class="changeStatus cancel ml-1"><i class="material-icons">cancel</i></a>';
                        }
                        return $btn;
                    })

                    ->rawColumns(['id','display_order_id','order_date','order_status_action','order_time','customer_name','customer_mobile_no','restaurant_name','table_no','fooditems','quantity','total_amount_pay','order_status','action'])
                    ->make(true);
        }

        return view('admin.orders.list',compact('total_order','past_order','new_order'));
    }
public function pastorders(Request $request) {
       
        $total_order = Orders::where('payment_method','!=','p')->count();
        $count = Orders::select('orders.*','users.restaurant_name')->where('payment_method','!=','p')->with('orderdetails')
                ->leftjoin('users','users.id','=','orders.restaurant_id')
                ->count();
            $skip = 20;
            $limit = $count - $skip; 
                $data = Orders::select('orders.*','users.restaurant_name')->whereIN('orders.order_status',array('co','cn'))->where('payment_method','!=','p')->with('orderdetails')->orderBy('id','DESC')
                ->leftjoin('users','users.id','=','orders.restaurant_id')
                ->get();
        $past_order = count($data);

        if ($request->ajax()) {
           

            return Datatables::of($data)
                    ->addIndexColumn()
                     ->addColumn('id', function($row){
                        return $row['id'];
                    })
                  ->addColumn('display_order_id', function($row){
                        return 'order'.$row['display_order_id'];
                    })
                    ->addColumn('order_date', function($row){
                        return date('d-m-Y', strtotime($row->created_at));
                    })
                    ->addColumn('order_time', function($row){
                        return date('h:i A', strtotime($row->created_at));
                    })
                    ->addColumn('customer_name', function($row){
                        if($row->customer_name != ''){
                            return $row->customer_name;
                        }else{
                            return 'guest';
                        }
                    })
                    ->addColumn('payment_method', function($row){
                        if($row->payment_method == 'ca'){
                            return 'Card';
                        }else{
                            return 'Cash';
                        }
                    })
                    ->addColumn('customer_mobile_no', function($row){
                        return $row['customer_mobile_no'];
                    })
                    ->addColumn('restaurant_name', function($row){
                        return $row['restaurant_name'];
                    })
                     ->addColumn('table_no', function($row){
                        return $row['table_no'];
                    })

                     
                 ->addColumn('fooditems', function($row){
                    if(!empty($row['orderdetails'])){
                        $foodname = array();
                        foreach($row['orderdetails'] as $fooditems){
                            $foodname[] = $fooditems['food_name'];
                        }
                        return implode(',',$foodname);
                        
                    }else{
                        return '';
                    }

                    })
                      ->addColumn('quantity', function($row){
                    if(!empty($row['orderdetails'])){
                        $quantity = 0;
                        foreach($row['orderdetails'] as $fooditems){
                            $quantity = $quantity + $fooditems['quantity'];
                        }
                        return $quantity;
                        
                    }else{
                        return '';
                    }
                    })
                       ->addColumn('total_amount_pay', function($row){
                        return number_format($row['total_amount_pay'],2).' '.config('constant.CURRENCY');
                    })
                        ->addColumn('order_status_action', function($row){
                            if($row['order_status'] == 'a')
                                    return 'Accepted';
                            elseif($row['order_status'] == 'p')
                                    return 'Preparing';
                            elseif($row['order_status'] == 'c')
                                    return 'Coming';
                            elseif($row['order_status'] == 's')
                                    return 'Served';
                            elseif($row['order_status'] == 'co')
                                    return 'Completed';
                            elseif($row['order_status'] == 'cn')
                                    return 'Cancelled';
                            else
                                    return 'Pending';                                       
                        })
                        
                       ->addColumn('order_status', function($row){
                          return $row['order_status'];  
                     })
                    ->addColumn('action', function($row){
                        $urlpath = url('admin/orders');
                        return '<a href="'.$urlpath.'/view/'. $row->id .'" class="view"><i class="material-icons">visibility</i></a>';
                    })

                    ->rawColumns(['id','display_order_id','order_date','order_time','order_status_action','customer_name','customer_mobile_no','restaurant_name','table_no','fooditems','quantity','total_amount_pay','order_status','action'])
                    ->make(true);
        }

        return view('admin.orders.list',compact('total_order','past_order'));
    }
     public function changeStatus(Request $request){

        $order = Orders::find($request->id);
        $order->order_status = $request->orderstatus;
        $order->update();
        return response()->json([
            'success' => 'status has been changed successfully!'
        ]);
    }

    public function delete($id){
        $user = Bannerdeals::find($id);

        if($user->is_deleted == '1'){
            $user->is_deleted = "0";
        } else {
            $user->is_deleted = "1";
        }
        $user->update();

       return response()->json([
            'success' => 'Record has been deleted successfully!'
        ]);
       
    }

    public function view($id) {

        $order = Orders::select('orders.*','users.restaurant_name')
        ->where('orders.id',$id)
        ->with('orderdetails')
                ->leftjoin('users','users.id','=','orders.restaurant_id')
                ->first();

        return view('admin.orders.view')->with('order',$order);
    }
     public function cancelorder(Request $request){
        //    dd($request->all());
        $order = Orders::find($request->order_id);
      
             $orderdetails = Orderdetail::where('order_id',$order->id)->get()->toArray();
             foreach($orderdetails  as $orderdetail){

                  $fooditem = Fooditems::find($orderdetail['product_id']);
                  $fooditem->available_qty = $fooditem->available_qty + $orderdetail['quantity'];
                  $fooditem->update();

             }

        $order->order_status = 'cn';
        $order->cancel_order_reson = $request->reason;
        if($order->payment_method == 'ca'){
            $refund =  TapPayment::refund($order);
        }
        //$order->cancel_order_reson = json_encode($refund);
       // dd($refund);
        $order->update();
        $title = 'Order cancel';
        $message = '<a href='.route("customer.orderlist").'> your Order'. $order->display_order_id.' is cancelled with <b>Reason </b>' .$order->cancel_order_reson.'</a>';
        NotificationHelper::customernotification($order,$title,$message);
        return redirect()->route('admin.orders.list')->with('message', 'Order cancel successfully');
    }
}
