<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Payout;
use DataTables;
use Mail;
use App\Helpers\s3upload;
use App\Helpers\Admin;
use Session;
use DB;

class PayoutController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $permission = Admin::checkPermission(Session::get('user_id'), 'Users', 'View');

        if ($permission == 0) {

            return redirect()->route('admin.dashboard')->with('message', 'You dont have permission to do this action')->send();
        } else {
            if ($request->ajax()) {

                // DB::enableQueryLog();
                // $db = Product::select('tbl_product.id', 'tbl_product.product_categories_id', 'tbl_product.name', 'tbl_product.description', 'tbl_product.is_active', 'c.name as cat_name', 'c.id as cat_id')
                // ->join('tbl_product_categories as c', 'tbl_product.product_categories_id', 'c.id')
                // // ->join('tbl_product_variant','tbl_product.id','tbl_product_variant.product_id')
                // // ->join('tbl_color','tbl_product_variant.color_id','tbl_color.id')
                // ->where('tbl_product.is_delete', '0')
                // ->get();

                // dd(DB::getQueryLog());

                $data = Payout::select('tbl_invoice.id','us.full_name as user_name','tbl_invoice.total','tbl_invoice.paid','b.account_holder_name','b.account_number','b.routing_number','tbl_invoice.created_at','tbl_invoice.is_settled')
                ->join('tbl_schedule_inspection as si', 'si.id', 'tbl_invoice.inspection_id')
                ->join('tbl_bank_detail as b', 'si.inspector_id', 'b.user_id')
                ->join('tbl_user as us', 'si.inspector_id', 'us.id')
                ->whereNotNull('tbl_invoice.total')
                ->where('tbl_invoice.is_deleted','0')->get();
                // dd($data[0]);
                return Datatables::of($data)
                    ->addIndexColumn()
                    // ->addColumn('profile_image', function($row){
                    //     $url= env('project_image_path').'profile/'.$row->profile_image;
                    //     return '<img src="'.$row->profile_image.'" border="0" width="40" class="img-rounded" align="center" />';
                    // })
                    ->addColumn('id', function ($row) {
                        return $row->id;
                    })
                    ->addColumn('user_name', function ($row) {
                        return $row->user_name;
                    })
                    ->addColumn('total', function ($row) {
                        return $row->total;
                    })
                    ->addColumn('paid', function ($row) {
                        return $row->paid;
                    })
                    ->addColumn('account_holder_name', function ($row) {
                        return $row->account_holder_name;
                    })
                    ->addColumn('account_number', function ($row) {
                        return $row->account_number;
                    })
                    ->addColumn('routing_number', function ($row) {
                        return $row->routing_number;
                    })
                    ->addColumn('createdat', function ($row) {
                        return date('d-m-Y', strtotime($row->created_at));
                    })
                    ->addColumn('is_settled', function ($row) {
                        return $row->is_settled;
                    })
                    ->addColumn('action', function ($row) {
                        $urlpath = url('admin/payout');
                        $btn = '';

                        $btn .= '<a href="'.$urlpath.'/view/'. $row->id .'"  data-toggle="tooltip" data-id="' . $row->id . '" data-original-title="Show" class="btn btn-raised waves-effect waves-float waves-green"><i class="zmdi zmdi-eye"></i></a>&nbsp;';

                        return $btn;
                        // return '<div class="btn-group dot-view-acation"><a href="#" data-toggle="dropdown" class="btn btn-default btn-sm btn-icon-only transparent" title=""><i class="zmdi zmdi-more"></i></a>
                        //     <div class="dropdown-menu dropdown-icon-menu dropdown-menu-right"> 
                        //                          <a href="'.$urlpath.'/view/'. $row->id .'" class="dropdown-item"><i class="zmdi zmdi-eye zmdi-hc-fw text-secondary"></i>View</a>
                        //                          '.$btn.'</div></div>';
                    })
                    ->rawColumns(['user_name', 'inspector_name', 'total', 'paid', 'account_holder_name', 'account_number','routing_number','createdat','is_settled','action'])
                    ->make(true);
            }
            return view('admin.payout.list');
        }
    }

    public function edit($id)
    {
        $user = Report::find($id)->toArray();
        return view('admin.users.edit')->with('user', $user);
    }

    public function sendMail($email, $link)
    {
        $email1 = base64_decode($email);
        $link1 = base64_decode($link);
        // dd($email,$link);
        $data['details'] = [
            'title' => 'Your report link',
            'body' => 'Download link: ' . $link1,
        ];

        // Mail::to('harsh1ghediya@gmail.com')->send(new \App\Mail\MyTestMail($details));
        Mail::send('emails.myTestMail', $data, function ($message) use ($email1, $link1) {
            $message->to($email1);
            $message->subject('Homespector');
            // $message->from('goaldiggershlinkteam@gmail.com','Homespector');
            $message->subject('Report link');
        });
        return view('admin.report.list');
    }
    public function update(Request $request)
    {
        $user = Report::find($request->user_id);
        $user->full_name = $request->full_name;
        $user->mobile_number = $request->mobile_number;
        $user->email = $request->email;
        $user->is_active = $request->is_active;
        if ($request->has('profile_image')) {
            $file1 = $request->file()['profile_image'];
            $imageName = $file1->getClientOriginalName();
            $file = $_FILES['profile_image']['tmp_name'];
            $path = env('AWS_BUCKET_FOLDER') . env('USER_IMAGE');
            $contents = s3upload::uploadImage($imageName, $file, $path); // calling helper function
            $user->profile_image = $contents;
        }
        $user->update();
        return redirect()->route('admin.user.list')->with('message', 'User record updated successfully!');
    }

    public function delete($id)
    {
        Report::find($id)->delete();
        return response()->json([
            'success' => 'Record has been deleted successfully!'
        ]);
        // return redirect()->route('admin.user.list')->with('message', 'User record delete successfully!');
    }

    public function changeStatus($id)
    {
        $user = Payout::find($id);
        if ($user->is_settled == 1) {
            $user->is_settled = "0";
        } else {
            $user->is_settled = "1";
        }
        $user->update();
        
        return response()->json([
            'success' => 'Record settlement has been changed successfully!'
        ]);
    }

    public function view($id)
    {
        $user = Payout::select('tbl_invoice.id','us.full_name as user_name','tbl_invoice.total','tbl_invoice.paid','b.account_holder_name','b.account_number','b.routing_number','tbl_invoice.created_at','tbl_invoice.is_settled')
        ->join('tbl_schedule_inspection as si', 'si.id', 'tbl_invoice.inspection_id')
        ->join('tbl_bank_detail as b', 'si.inspector_id', 'b.user_id')
        ->join('tbl_user as us', 'si.inspector_id', 'us.id')
        ->whereNotNull('tbl_invoice.total')
        ->where('tbl_invoice.is_deleted','0')
        ->firstWhere('tbl_invoice.id',$id)->toArray();
        
        return view('admin.payout.view', compact('user'));
    }
}
