<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Cms;
use DataTables;
use App\Helpers\Admin;
use Session;
use App\Helpers\s3upload;

class StaticPageController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
       $permission = Admin::checkPermission(Session::get('user_id'),'Static Content','View');
    
      if($permission == 0){
        
           return redirect()->route('admin.dashboard')->with('message','You dont have permission to do this action')->send();


      }else{
       
        if ($request->ajax()) {
             $data = Cms::where('is_deleted','0')->get();
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('page_description', function($row){
                        return strip_tags($row->page_description);
                    })
                    ->addColumn('created_at', function($row){
                        return date('d-m-Y', strtotime($row->created_at));
                    })
                    ->addColumn('updated_at', function($row){
                        return date('d-m-Y', strtotime($row->updated_at));
                    })
                    ->addColumn('action', function($row){
                        $urlpath = url('admin/staticcontent');
                        $update = Admin::checkPermission(Session::get('user_id'),'Static Content','Update');
                        $delete = Admin::checkPermission(Session::get('user_id'),'Static Content','Delete');
                   $btn = '';
                      if($update == 1){
                            $btn = '<a href="'.$urlpath.'/edit/'. $row->id .'" class="dropdown-item"><i class="zmdi zmdi-edit zmdi-hc-fw text-secondary"></i>Edit</a>';
                        }
                        // if($delete == 1){
                        //     $btn .= '<a href="javascript:void(0);" onClick="deleteFunc('.$row->id.')" class="dropdown-item"><i class="zmdi zmdi-delete zmdi-hc-fw text-secondary"></i>Delete</a>';
                        // }

                        return '<div class="btn-group dot-view-acation"><a href="#" data-toggle="dropdown" class="btn btn-default btn-sm btn-icon-only transparent" title=""><i class="zmdi zmdi-more"></i></a>
                            <div class="dropdown-menu dropdown-icon-menu dropdown-menu-right"> 
                                                 '.$btn.'</div></div>';
                        
                    })
                    ->rawColumns(['page_description','created_at','updated_at','action'])
                    ->make(true);
        }
        
        return view('admin.staticpage.list');
    }
    }

    public function add()
    {
        return view('admin.staticpage.add');
    }

    public function store(Request $request) {
        $this->validate($request, [
            'content' => 'required',
            'page_name' => 'required',
        ]);
        $page = new Cms();
        $page->page_name  = str_replace(' ', '-', strtolower($request->page_description));
        $page->page_description = $request->page_description;
        $page->content = $request->content;
         if($request->has('content_image')){
                $file1 = $request->file()['content_image'];
                $imageName=$file1->getClientOriginalName();
                $file = $_FILES['content_image']['tmp_name'];
                $path = env('AWS_BUCKET_FOLDER') . env('CONTENT_IMAGE');
                $contents = s3upload::uploadImage($imageName, $file, $path); // calling helper function
                $page->content_image = $contents;
            }

        $page->save();
        return redirect()->route('admin.staticpages.list')->with('message', 'Page record added successfully!');
    }

    public function edit($id) {
        $page = Cms::find($id)->toArray();
      //  dd($page);
        return view('admin.staticpage.edit')->with('page',$page);
    }

    public function update(Request $request){
         $this->validate($request, [
            'content' => 'required',
            'page_description' => 'required',
        ]);

        $page = Cms::find($request->id);
        $page->page_description = $request->page_description;
        $page->content = $request->content;
          if($request->has('content_image')){
                $file1 = $request->file()['content_image'];
                $imageName=$file1->getClientOriginalName();
                $file = $_FILES['content_image']['tmp_name'];
                $path = env('AWS_BUCKET_FOLDER') . env('CONTENT_IMAGE');
                $contents = s3upload::uploadImage($imageName, $file, $path); // calling helper function
                $page->content_image = $contents;
            }

        $page->update();
        return redirect()->route('admin.staticpages.list')->with('message', 'Pages record updated successfully!');
    }

    public function delete($id){
        $page = Cms::find($id);
        if($page->is_deleted == '1'){
            $page->is_deleted = "0";
        } else {
            $page->is_deleted = "1";
        }
        $page->update();
        return response()->json([
            'success' => 'Record has been deleted successfully!'
        ]);
        // return redirect()->route('admin.staticpage.list')->with('message', 'Pages record delete successfully!');
    }

    public function changeStatus($id){
        $page = Cms::find($id);
        if($page->status == 'active'){
            $page->status = "inactive";
        } else {
            $page->status = "active";
        }
        $page->update();
        return response()->json([
            'success' => 'Record status has been changed successfully!'
        ]);
    }

    public function view($id) {
        $page = Cms::find($id)->toArray();
        return view('admin.staticpage.view')->with('page',$page);
    }

    public function index_aboutus()
    {
        $data = Cms::where('id', 1)->first();
        return view('staticpage.aboutus', compact('data'));
    }

    public function index_privacypolicy()
    {
        $data = Cms::where('id', 3)->first();
        return view('staticpage.privacypolicy', compact('data'));
    }
        
    public function index_termscondition()
    {
        $data = Cms::where('id', 2)->first();
        return view('staticpage.terms', compact('data'));
    }
    public function index_faqs()
    {
        $faqs = FAQ::where('is_active', '1')->where('is_delete', '0')->get();
        return view('faqs.faqs', compact('faqs'));
    }
}
