<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\Http\Controllers\Controller;
use App\Models\Admin as AdminUser;
use App\Models\AdminPermission;
use App\Models\AdminRolePermissions;
use Yajra\DataTables\DataTables;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Carbon;
use App\Models\SubFeature;
use Illuminate\Support\Facades\Mail;
use Session;
use App\Helpers\Admin;
use App\Models\Activity_log;
use Illuminate\Support\Str;


class SubAdminController extends Controller
{
    // public function add(Request $request)
    // {
    //     return view("admin.manage_subadmins");
    // }

  public function index(Request $request)
  {
    $permission = Admin::checkPermission(Session::get('user_id'),'Sub Admins','View');
    
    if($permission == 0){
      
      return redirect()->route('admin.dashboard')->with('message','You dont have permission to do this action')->send();



    }else{
      if ($request->ajax())
      {
        $data = AdminUser::where('role','=','2')->where('is_deleted','=','0')->get();
        return Datatables::of($data)
        ->addIndexColumn()
        
        ->addColumn('name', function($row){
          return $row->name;
        })
        ->addColumn('email', function($row){
          return $row->email;
        })
        ->addColumn('created_at', function($row){
          return date('d-m-Y',strtotime($row->created_at));
        })
        
        ->addColumn('status', function($row){
          return $row->status;
        })
        
        ->addColumn('action', function($row){
          $urlpath = url('admin/subadmins');

          $update = Admin::checkPermission(Session::get('user_id'),'Sub Admins','Update');
          $delete = Admin::checkPermission(Session::get('user_id'),'Sub Admins','Delete');
          $btn = '';
          if($update == 1){
            $btn = '<a href="javascript:void(0);" onClick="changeStatus('.$row->id.')" class=" dropdown-item"><i class="zmdi zmdi-account zmdi-hc-fw text-secondary"></i>Active/Inactive</a> <a href="'.$urlpath.'/edit/'. $row->id .'" onClick="adminVerify('.$row->id.')" class=" dropdown-item"><i class="zmdi zmdi-edit zmdi-hc-fw text-secondary"></i>Edit</a>';
          }
          if($delete == 1){
            $btn.= '<a href="javascript:void(0);" onClick="deleteFunc('.$row->id.')" class=" dropdown-item"><i class="zmdi zmdi-delete zmdi-hc-fw text-secondary"></i>Delete</a>';
          }

          return '<div class="btn-group dot-view-acation"><a href="#" data-toggle="dropdown" class="btn btn-default btn-sm btn-icon-only transparent" title=""><i class="zmdi zmdi-more"></i></a>
          <div class="dropdown-menu dropdown-icon-menu dropdown-menu-right"> 
          <a href="'.$urlpath.'/view/'. $row->id .'" class="dropdown-item"><i class="zmdi zmdi-eye zmdi-hc-fw text-secondary"></i>View</a>
          '.$btn.'</div></div>';
                  // return '<a href="'.$urlpath.'/edit/'. $row->id .'" class="edit"><i class="material-icons">edit</i></a>
                  // <a href="javascript:void(0);" onClick="deleteFunc('.$row->id.')" class="delete"><i class="material-icons">delete</i></a>';
        })
        ->rawColumns(['name','email','created_at','status','action'])
        ->make(true);
      }
      return view('admin.subadmins.list');
    }
  }

  public function activateordeactivate($id)
  {
    $user = AdminUser::find($id);
    if($user->status == '1'){
      $user->status = "0";
    } else {
      $user->status = "1";
    }
    $user->update();
    return response()->json([
      'success' => 'Record status has been changed successfully!'
    ]);
  }

  public function delete($id){
    
    try {
      $userdetail = AdminUser::find($id);
      $userdetail->deleted_at = Carbon::now();
      $userdetail->is_deleted = '1';
      $userdetail->update();
      return response()->json([
        'success' => 'Sub admin has been deleted successfully!'
      ]);
    } catch (ModelNotFoundException $e) {
      return response()->json([
        'success' => 'Oops...Sub Admin User Not found!'
      ]);
      
    }
  }

  public function ShowAddSubAdminForm(Request $request)
  {
    $features = AdminRolePermissions::with(['subpermissionOrderBySequence'])->get();
    
    return view('admin.subadmins.add', ['features' => $features]);
  }

  public function SubmitNewSubAdminForm(Request $request)
  {
    $finduser = AdminUser::where('email', $request->email)->where('is_deleted','=','0')->first();
    if (!empty($finduser)) {
     return redirect()->route('admin.subadmins.list')->with('error', 'Try with different email!');
   }else {
    $add_sub = new AdminUser();
    $add_sub->role = "2";
    $add_sub->name = $request->name;
    $add_sub->email = $request->email;
        //$psw = "Plattir@".mt_rand(1000, 9999);
    $psw = Str::random(8);
    
    $add_sub->password = Hash::make($psw);
    if($add_sub->save())
    {
      if(!empty($request->subfeature)){
        foreach ($request->subfeature as $key => $value) {
          $admin_per = new AdminPermission();
          $admin_per->admin_id = $add_sub->id;
          $admin_per->permission_id = $value;
          $admin_per->save();
        }
      }
      Mail::send('email.subadmin-email', ['email' => $add_sub->email, 'password' => $psw,  'name' => $add_sub->name], function ($message) use ($add_sub) {
        $message->to($add_sub->email, $add_sub->name)->subject('Plattir admin account');
        $message->from(env('MAIL_FROM_ADDRESS'), env('MAIL_FROM_NAME'));
      });
      return redirect()->route('admin.subadmins.list')->with('message', 'Sub admin successfully added!');
         // return response()->json(['code' => 1, 'error' => 'Sub admin successfully added!']);
    }else {
     return redirect()->route('admin.subadmins.list')->with('error', 'Something went wrong please try again!');
     
   }


 }
}

public function edit(AdminUser $user)
{
      // $permission = AdminPermission::where('admin_id',$user->id)->pluck('permission_id')->toArray();
  $permission = AdminPermission::select('admin_permissions.permission_id')
  ->join('admin_role_sub_permissions','admin_role_sub_permissions.id','=','admin_permissions.permission_id')
  ->join('admin_role_permissions','admin_role_permissions.id','=','admin_role_sub_permissions.parent_admin_role_permission_id')
  ->where('admin_permissions.admin_id',$user->id)
  ->pluck('permission_id')->toArray();

  $parent_permission = AdminPermission::select('admin_role_sub_permissions.parent_admin_role_permission_id')
  ->join('admin_role_sub_permissions','admin_role_sub_permissions.id','=','admin_permissions.permission_id')
  ->join('admin_role_permissions','admin_role_permissions.id','=','admin_role_sub_permissions.parent_admin_role_permission_id')
  ->where('admin_permissions.admin_id',$user->id)
  ->pluck('parent_admin_role_permission_id')->toArray();

  $features = AdminRolePermissions::with(['subpermissionOrderBySequence'])->get();
  return view('admin.subadmins.edit', ['user'=>$user,'features' => $features,'permission'=>$permission,'parent_permission'=>$parent_permission]);
}

public function SubmitEditSubAdminForm(Request $request)
{
  $finduser = AdminUser::where('email', $request->email)->first();
  if (empty($finduser)) {
   return response()->json(['code' => 0, 'error' => 'sameemail']);
 }else {
  $add_sub = AdminUser::where('id', $request->id)->first();
  $add_sub->name = $request->name;
  $add_sub->email = $request->email;
  if($add_sub->save())
  {
    AdminPermission::where('admin_id',$request->id)->delete();
    if(!empty($request->subfeature)){
      foreach ($request->subfeature as $key => $value)
      {
        $admin_per = new AdminPermission();
        $admin_per->admin_id = $add_sub->id;
        $admin_per->permission_id = $value;
        $admin_per->save();
      }
    }
    return redirect()->route('admin.subadmins.list')->with('message', 'Sub admin successfully updated!');
  }else {
   return redirect()->route('admin.subadmins.list')->with('message', 'Something went wrong please try again!');
   
 }


}
}
public function view($id) {

  $subadmins = AdminUser::find($id);
  $permission = AdminPermission::select('admin_permissions.permission_id')
  ->join('admin_role_sub_permissions','admin_role_sub_permissions.id','=','admin_permissions.permission_id')
  ->join('admin_role_permissions','admin_role_permissions.id','=','admin_role_sub_permissions.parent_admin_role_permission_id')
  ->where('admin_permissions.admin_id',$id)
  ->pluck('permission_id')->toArray();

  $parent_permission = AdminPermission::select('admin_role_sub_permissions.parent_admin_role_permission_id')
  ->join('admin_role_sub_permissions','admin_role_sub_permissions.id','=','admin_permissions.permission_id')
  ->join('admin_role_permissions','admin_role_permissions.id','=','admin_role_sub_permissions.parent_admin_role_permission_id')
  ->where('admin_permissions.admin_id',$id)
  ->pluck('parent_admin_role_permission_id')->toArray();

  $features = AdminRolePermissions::with(['subpermissionOrderBySequence'])->get();
  $activity_log = Activity_log::where('user_id',$id)->where('user_type','sa')->get();
  return view('admin.subadmins.view', compact('subadmins','permission','parent_permission','features','activity_log'));
}
}
