<?php

namespace App\Http\Controllers;

use DB;
use Mail;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use GuzzleHttp\Exception\GuzzleException;
use GuzzleHttp\Client;
use App\Helpers\s3upload;
use GuzzleHttp\Exception\ConnectException;

class Inspection_details extends Controller
{
    use ConsumeExternalService;

    public function get_inspection_details(Request $request)
    {
        $data['id'] = $request->id;
        $headerData['token'] = Session::get('token');

        $postData = EncryptDecrypt::bodyEncrypt(json_encode($data));

        // Perform first API request
        $response = $this->performRequest("POST", "/api/v1/user/getscheduleinspection", $postData, $headerData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if ($response_decoded->code == 1) {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;

            $realtor_id = $response_decoded->data->realtor_info;

            $realtorToken['token'] = Session::get('token');
            $realtorData = EncryptDecrypt::bodyEncrypt(json_encode(['id' => $realtor_id]));

            // Perform second API request
            $rel_response = $this->performRequest("POST", "/api/v1/user/realtorlist", $realtorData, $realtorToken);
            $realtor_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($rel_response));

            if ($realtor_response_decoded->code == 1) {
                $data['realtor_code'] = $realtor_response_decoded->code;
                $data['realtor_data'] = $realtor_response_decoded->data;
            } else {
                $data['realtor_code'] = $realtor_response_decoded->code;
                $data['realtor_data'] = [];
            }
        } else {
            $data['code'] = $response_decoded->code;
            $data['data'] = [];
            $data['realtor_code'] = 0;
            $data['realtor_data'] = [];
        }


        return view('website.inspection-details', $data);
    }


    // -----------EDIT INSPECTION DETAILS ---------------------------


    public function edit_inspection_details(Request $request)
    {

        $data['id'] = $request->id;
        $headerData['token'] = Session::get('token');

        $postData = EncryptDecrypt::bodyEncrypt(json_encode($data));

        // Perform first API request
        $response = $this->performRequest("POST", "/api/v1/user/getscheduleinspection", $postData, $headerData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if ($response_decoded->code == 1) {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;

            $realtor_id = $response_decoded->data->realtor_info;

            Session::put('realtor_id', $realtor_id);


            $realtorToken['token'] = Session::get('token');
            $realtorData = EncryptDecrypt::bodyEncrypt(json_encode(['id' => $realtor_id]));

            // Perform second API request
            $rel_response = $this->performRequest("POST", "/api/v1/user/realtorlist", $realtorData, $realtorToken);
            $realtor_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($rel_response));

            if ($realtor_response_decoded->code == 1) {
                $data['realtor_code'] = $realtor_response_decoded->code;
                $data['realtor_data'] = $realtor_response_decoded->data;
            } else {
                $data['realtor_code'] = $realtor_response_decoded->code;
                $data['realtor_data'] = [];
            }
        } else {
            $data['code'] = $response_decoded->code;
            $data['data'] = [];
            $data['realtor_code'] = 0;
            $data['realtor_data'] = [];
        }

        // dd($data);



        return view('website/edit-schedule-inspection', $data);
    }



    public function post_edit_inspection(Request $request)
    {
        // Prepare data for inspection edit
        $data['id'] = $request->id;
        $data['client_info']['client_name'] = $request->client_name;
        $data['client_info']['email'] = $request->email;
        $data['client_info']['country_code'] = $request->country_code;
        $data['client_info']['phone_number'] = $request->phone_number;
        $data['client_info']['private_note'] = $request->private_note;
        $data['phone'] = $request->phone;
        $data['inspection_date_time'] = $request->inspection_date_time;
        $data['inspection_address'] = $request->inspection_address;


        $headerData['token'] = Session::get('token');
        $postData = EncryptDecrypt::bodyEncrypt(json_encode($data));
        $response = $this->performRequest("POST", "/api/v1/user/editinspection", $postData, $headerData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);
        if ($response_decoded->code == 1) {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;
        } else {
            $data['code'] = $response_decoded->code;
            $data['data'] = [];
        }

        // Prepare data for realtor edit

        $realtor_id = Session::get('realtor_id');

        $realtor_data['realtor_id'] = $realtor_id;
        $realtor_data['realtor_info']['realtor_name'] = $request->realtor_name;
        $realtor_data['realtor_info']['email'] = $request->realtor_email;
        $realtor_data['realtor_info']['country_code'] = $request->realtor_country_code;
        $realtor_data['realtor_info']['phone_number'] = $request->realtor_phone_number;

        // dd($realtor_data);

        $raltor_postData = EncryptDecrypt::bodyEncrypt(json_encode($realtor_data));
        $rel_response = $this->performRequest("POST", "/api/v1/user/editrealtor", $raltor_postData, $headerData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($rel_response));
        // dd($response_decoded);


        if (isset($response_decoded->code) && $response_decoded->code == 1) {
            $data['realtor_code'] = $response_decoded->code;
            if (isset($response_decoded->data)) {
                $data['realtor_data'] = $response_decoded->data;
            } else {
                $data['realtor_data'] = [];
            }
        } else {
            $data['realtor_code'] = $response_decoded->code;
            $data['realtor_data'] = [];
        }


        return redirect()->route('website.home');
    }

    // --------------------------------delete inspection-----------------------------

    public function delete_inspection(Request $request)
    {

        $data['id'] = $request->id;
        // $inspectionDetail['token'] = Session::get('token');


        $headerData['token'] = Session::get('token');
        $postData = EncryptDecrypt::bodyEncrypt(json_encode($data));
        $response = $this->performRequest("POST", "/api/v1/user/deleteinspection", $postData, $headerData);
        // dd($response); 
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        // dd($response_decoded);

        // if ($response_decoded->code == 1) {
        //     $data['code'] = $response_decoded->code;
        //     $data['data'] = $response_decoded->data;
        // } else {
        //     $data['code'] = $response_decoded->code;
        //     $data['data'] = [];
        // }

        return redirect()->route('website.home');
    }



    // -------------------------------ALL INSPECTION LIST----------------------------

    public function all_inspection_details(Request $request)
    {

        $currentDate = date('j F, Y');

        // Get user info

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/userinfo", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = $response_decoded->data;
        } else {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = [];
        }

        // Get schedule inspection list

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/scheduleinspectionlist", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;

            // Count the number of inspections
            $data['inspection_count'] = count($data['data']);
        } else {
            $data['code'] = $response_decoded->code;
            $data['data'] = [];
            $data['inspection_count'] = 0;
        }

        $data['currentDate'] = $currentDate;
        // dd($data);

        return view('website.all-inspection', $data);
    }


    // --------------PENDING-----------------

    public function all_inspection_pending(Request $request)
    {

        $currentDate = date('j F, Y');

        // Get user info

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/userinfo", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = $response_decoded->data;
        } else {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = [];
        }

        // Get schedule inspection list

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/scheduleinspectionlist", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;

            // Count the number of inspections
            $data['pending_inspection_count'] = count($data['data']);
        } else {
            $data['code'] = $response_decoded->code;
            $data['data'] = [];
            $data['pending_inspection_count'] = 0;
        }

        $data['currentDate'] = $currentDate;
        // dd($data);

        return view('website.all-inspection-pending', $data);
    }


    public function all_inspection_progress(Request $request)
    {

        $currentDate = date('j F, Y');

        // Get user info

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/userinfo", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = $response_decoded->data;
        } else {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = [];
        }

        // Get schedule inspection list

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/scheduleinspectionlist", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;

            // Count the number of inspections
            $data['inspection_count'] = count($data['data']);
        } else {
            $data['code'] = $response_decoded->code;
            $data['data'] = [];
            $data['inspection_count'] = 0;
        }

        $data['currentDate'] = $currentDate;
        // dd($data);

        return view('website.all-inspection-progress', $data);
    }


    public function all_inspection_saved(Request $request)
    {

        $currentDate = date('j F, Y');

        // Get user info

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/userinfo", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = $response_decoded->data;
        } else {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = [];
        }

        // Get schedule inspection list

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/scheduleinspectionlist", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;

            // Count the number of inspections
            $data['inspection_count'] = count($data['data']);
        } else {
            $data['code'] = $response_decoded->code;
            $data['data'] = [];
            $data['inspection_count'] = 0;
        }

        $data['currentDate'] = $currentDate;
        // dd($data);

        return view('website.all-inspection-saved', $data);
    }



    // ----------------------CALENDAR-------------------------

    public function calendar(Request $request)
    {
        return view('website.calendar');
    }
}
