@extends('layout.admin')
@section('title') Add Banner @endsection
@section('css')
<link href="{{ asset('assets/plugins/bootstrap-material-datetimepicker/css/bootstrap-material-datetimepicker.css') }}" rel="stylesheet" />
@endsection
@section('content')
<div class="container-fluid">
    <div class="row page-titles">
        <div class="col-md-5 align-self-center">
            <h4 class="text-themecolor">Banners </h4>
        </div>
        <div class="col-md-7 align-self-center text-right">
            <div class="d-flex justify-content-end align-items-center">
                <ol class="breadcrumb">
                    <li class="breadcrumb-item active">Banners</li>
                </ol>
            </div>
        </div>
    </div>
    <section class="content home">
        <div class="block-header">
            <div class="row">
                <div class="col-lg-7 col-md-6 col-sm-12">
                    <h2>Add Banner
                        <small class="text-muted">Fill in the form and then click on submit</small>
                    </h2>
                </div>
                <div class="col-lg-5 col-md-6 col-sm-12">
                    <ul class="breadcrumb float-md-right">
                        <li class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}"><i class="zmdi zmdi-home"></i> Home</a></li>
                        <li class="breadcrumb-item"><a href="{{ route('admin.banner.list') }}"><i class="zmdi zmdi-store"></i> Banners</a></li>
                        <li class="breadcrumb-item active">Add</li>
                    </ul>
                </div>
            </div>
        </div>
        <div class="container-fluid">
            <div class="row clearfix">
                <div class="col-lg-12 col-md-12 col-sm-12">
                    @if(session()->has('message'))
                        <div class="alert alert-success">
                            {{ session()->get('message') }}
                        </div>
                    @endif
                    <div class="card">
                        <div class="header"><h2>Banner Add</h2></div>
                        <div class="body">
                            <form class="form" name="createDrawProduct" id="createDrawProduct" method="POST" enctype="multipart/form-data" action="{{ route('admin.banner.store') }}">
                                {{ csrf_field() }}
                                <div class="row clearfix">
                                    <div class="col-sm-6">
                                        <div class="form-group form-float">
                                            <div class="form-line focused @error('title') error @enderror">
                                                <input type="text" name="title" id="title" class="form-control" value="">
                                                <label class="form-label">Title</label>
                                            </div>
                                            @error('title')
                                                <label class="error" role="alert">{{ $message }}</label>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="col-sm-6">
                                        <div class="form-group form-float">
                                            <div class="form-line focused">
                                                <select name="category_id" id="category_id" class="form-control show-tick">
                                                    <option value="">Select</option>
                                                    @foreach($category as $cat)
                                                        <option value="{{$cat['id']}}">{{$cat['name']}}</option>
                                                    @endforeach
                                                </select>
                                                <label class="form-label">Category</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-sm-6">
                                        <div class="">
                                            <label class="form-label">Image</label>
                                            <div class="@error('banner') error @enderror">
                                                <input type='file' name="banner" onchange="readURL(this);" />
                                            </div>
                                            <img id="image" src="" class="image_style" alt="your image" style="display:none;" />
                                            @error('banner')
                                                <label class="error" role="alert">{{ $message }}</label>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="col-sm-6">
                                        <div class="form-group form-float">
                                            <label class="form-label"> Status</label>
                                            <div class=" @error('status') error @enderror">
                                                <input type="radio" id="active" name="status" value="active" />
                                                <label for="active">Active</label>
                                                <input type="radio" id="inactive" name="status" value="inactive" />
                                                <label for="inactive">Inactive</label>   
                                            </div>
                                            @error('status')
                                                <label class="error" role="alert">{{ $message }}</label>
                                            @enderror
                                        </div>
                                    </div>
                                </div>
                                <div class="row clearfix">
                                    <div class="col-md-6">
                                        <button class="btn btn-raised btn-primary waves-effect" type="submit" id="submit_form">SUBMIT</button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    
</div>
@endsection
@section('js')
<script src="{{ asset('assets/plugins/momentjs/moment.js') }}"></script>
<script src="{{ asset('assets/plugins/ckeditor/ckeditor.js') }}"></script>
<script>
    function readURL(input) {
        if (input.files && input.files[0]) {
            var reader = new FileReader();

            reader.onload = function (e) {
                $('#image')
                    .attr('src', e.target.result);
            };
            $('#image').css('display','block');
            reader.readAsDataURL(input.files[0]);
        }
    }
    $(document).ready(function () {
        $('#createDrawProduct').validate({ // initialize the plugin
            rules: {
                title: {
                    required: true
                },
                category_id: {  
                    required: true
                },
                status: {
                    required: true
                },
            },
            errorPlacement: function(error, element) {
                var placement = $(element).data('error');
                if (placement) {
                    $(placement).append(error)
                } else {
                    error.insertAfter(element);
                }
            }
        });
    });
</script>
@endsection