<?php

use App\Http\Controllers\Controller;
use App\Http\Controllers\Admin\AuthController as AdminAuthController;
use App\Http\Controllers\Admin\FooditemsController as FooditemsController;
use App\Http\Controllers\Admin\DashboardController as AdminDashboardController;
use App\Http\Controllers\Admin\UserController as UserController;
use App\Http\Controllers\Admin\ReportController as reportController;
use App\Http\Controllers\Admin\SubscriptionController as SubscriptionController;
use App\Http\Controllers\Admin\CustomNotification as CustomNotification;
use App\Http\Controllers\Admin\SettingController as SettingController;
use App\Http\Controllers\Admin\RestaruntController as RestaruntController;
use App\Http\Controllers\Admin\SubAdminController as SubAdminController;
use App\Http\Controllers\Admin\StaticPageController as AdminStaticPage;
use App\Http\Controllers\Admin\HomePageDesignContentController as AdminHomePageDesignStaticContent;
use App\Http\Controllers\Admin\FAQController as FAQController;
use App\Http\Controllers\Admin\OrderController as OrderController;
use App\Http\Controllers\Admin\PayoutController as payoutController;
use App\Http\Controllers\Admin\ReportController as Reports;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
 */



Route::get('/admin', [AdminAuthController::class, 'index'])->name('admin.login');
Route::prefix('admin')->group(function () {
    Route::post('check-login', [AdminAuthController::class, 'checkLogin'])->name('admin.login.check');
    Route::middleware(['activitylog'])->group(function () {
        Route::get('login', [AdminAuthController::class, 'index'])->name('admin.login');
        // Route::get('', [AdminAuthController::class, 'index']);
        Route::get('forgot-password', [AdminAuthController::class, 'forgotPassword'])->name('admin.forgot.password');
        Route::post('forgot-password/submit', [AdminAuthController::class, 'checkForgotPassword'])->name('admin.forgot.password.submit');
        Route::get('reset-password/{token}', [AdminAuthController::class, 'checkResetPasswordToken'])->name('admin.user.reset.password');
        Route::post('reset-password/update/{token}', [AdminAuthController::class, 'setNewPassword'])->name('admin.reset.password.update');
        Route::post('isEmailAvailable', [AdminAuthController::class, 'isEmailAvailable'])->name('admin.isEmailAvailable');
        Route::middleware(['login', 'disablepreventback', 'admin'])->group(function () {
            Route::get('logout', [AdminAuthController::class, 'logout'])->name('admin.logout');
            Route::get('dashboard', [AdminDashboardController::class, 'dashboard'])->name('admin.dashboard');
            Route::get('change-password', [AdminAuthController::class, 'changePassword'])->name('admin.change.password');
            Route::post('change-password/update', [AdminAuthController::class, 'updatePassword'])->name('admin.change.password.update');
            Route::prefix('users')->group(function () {
                Route::get('add', [UserController::class, 'add'])->name('admin.user.add');
                Route::post('store', [UserController::class, 'store'])->name('admin.user.store');
                Route::match(array('GET','POST'),'/', [UserController::class, 'index'])->name('admin.user.list');
                Route::post('/', [UserController::class, 'index'])->name('admin.user.list');
                Route::get('edit/{user?}', [UserController::class, 'edit'])->name('admin.user.edit');
                Route::put('update', [UserController::class, 'update'])->name('admin.user.update');
                Route::get('view/{user?}', [UserController::class, 'view'])->name('admin.user.view');
                Route::get('delete/{user?}', [UserController::class, 'delete'])->name('admin.user.delete');
                Route::get('change/{user?}', [UserController::class, 'changeStatus'])->name('admin.user.change');
                Route::get('review/{user?}', [UserController::class, 'userReview'])->name('admin.user.review');
                Route::get('deleteReview/{user?}', [UserController::class, 'deleteReview'])->name('admin.user.deleteReview');
                Route::post('/view', [UserController::class, 'orderlist'])->name('admin.user.orderlist');
            });
            Route::prefix('reports')->group(function () {
                Route::get('add', [reportController::class, 'add'])->name('admin.reports.add');
                Route::post('store', [reportController::class, 'store'])->name('admin.reports.store');
                Route::match(array('GET','POST'),'/', [reportController::class, 'index'])->name('admin.reports.list');
                // Route::post('/', [reportController::class, 'index'])->name('admin.report.list');
                Route::get('edit/{user?}', [reportController::class, 'edit'])->name('admin.reports.edit');
                Route::put('update', [reportController::class, 'update'])->name('admin.reports.update');
                Route::get('view/{user?}', [reportController::class, 'view'])->name('admin.reports.view');
                Route::get('/send_mail/{email}/{link}', [reportController::class, 'sendMail'])->name('send_mail');
                Route::get('delete/{user?}', [reportController::class, 'delete'])->name('admin.reports.delete');
                Route::get('change/{user?}', [reportController::class, 'changeStatus'])->name('admin.reports.change');
                Route::get('review/{user?}', [reportController::class, 'userReview'])->name('admin.reports.review');
                Route::get('deleteReview/{user?}', [reportController::class, 'deleteReview'])->name('admin.reports.deleteReview');
                Route::post('/view', [reportController::class, 'orderlist'])->name('admin.reports.orderlist');
            });

            Route::prefix('payout')->group(function () {
                Route::get('add', [payoutController::class, 'add'])->name('admin.payout.add');
                Route::post('store', [payoutController::class, 'store'])->name('admin.payout.store');
                Route::match(array('GET','POST'),'/', [payoutController::class, 'index'])->name('admin.payout.list');
                // Route::post('/', [payoutController::class, 'index'])->name('admin.payout.list');
                Route::get('edit/{user?}', [payoutController::class, 'edit'])->name('admin.payout.edit');
                Route::put('update', [payoutController::class, 'update'])->name('admin.payout.update');
                Route::get('view/{user?}', [payoutController::class, 'view'])->name('admin.payout.view');
                
                Route::get('delete/{user?}', [payoutController::class, 'delete'])->name('admin.payout.delete');
                Route::get('change/{user?}', [payoutController::class, 'changeStatus'])->name('admin.payout.change');
                Route::get('review/{user?}', [payoutController::class, 'userReview'])->name('admin.payout.review');
                Route::get('deleteReview/{user?}', [payoutController::class, 'deleteReview'])->name('admin.payout.deleteReview');
                Route::post('/view', [payoutController::class, 'orderlist'])->name('admin.payout.orderlist');
            });

          

           

            Route::prefix('faq')->group(function () {

                Route::match(array('GET','POST'),'/', [FAQController::class, 'index'])->name('admin.faq.list');

                // Route::post('/', [FAQController::class, 'index'])->name('admin.faq.list');
                Route::get('add', [FAQController::class, 'add'])->name('admin.faq.add');

                Route::post('store', [FAQController::class, 'store'])->name('admin.faq.store');

                Route::get('delete/{faq?}', [FAQController::class, 'delete'])->name('admin.faq.delete');

                Route::get('edit/{faq?}', [FAQController::class, 'edit'])->name('admin.faq.edit');

                Route::put('update', [FAQController::class, 'update'])->name('admin.faq.update');

                Route::get('view', [FAQController::class, 'view'])->name('admin.faq.view');

                Route::get('change/{faq?}', [FAQController::class, 'changeStatus'])->name('admin.faq.change');
            });

            Route::prefix('notifications')->group(function () {

                Route::match(array('GET','POST'),'/', [CustomNotification::class, 'index'])->name('admin.notifications.list');
                // Route::post('/', [CustomNotification::class, 'index'])->name('admin.notifications.list');

                Route::get('add', [CustomNotification::class, 'add'])->name('admin.notifications.add');

                Route::get('delete/{id?}', [CustomNotification::class, 'delete'])->name('admin.notifications.delete');
                Route::post('/send', [CustomNotification::class, 'SendCustomNotification'])->name('admin.notifications.send');


                Route::get('GetUserWithtype/{type?}', [CustomNotification::class, 'GetUserWithtype'])->name('restaurant.notifications.GetUserWithtype');
            });

            Route::prefix('fooditems')->group(function () {

                Route::match(array('GET','POST'),'list', [FooditemsController::class, 'index'])->name('admin.fooditems.list');

                Route::match(array('GET','POST'),'add', [FooditemsController::class, 'fooditemadd'])->name('admin.fooditems.add');
                // Route::post('add', [FooditemsController::class, 'fooditemsubmit'])->name('admin.fooditems.add');

                // Route::post('list', [FooditemsController::class, 'index'])->name('admin.fooditems.list');
                Route::get('adminVerify/{id?}', [FooditemsController::class, 'adminVerify'])->name('admin.fooditems.adminVerify');
                Route::get('edit/{id?}', [FooditemsController::class, 'edit'])->name('admin.fooditems.edit');
                Route::put('update', [FooditemsController::class, 'update'])->name('admin.fooditems.update');
                Route::get('view/{id?}', [FooditemsController::class, 'view'])->name('admin.fooditems.view');
                Route::get('delete/{id?}', [FooditemsController::class, 'delete'])->name('admin.fooditems.delete');
                Route::get('change/{id?}', [FooditemsController::class, 'changeStatus'])->name('admin.fooditems.change');
                Route::get('deleteReview/{id?}', [FooditemsController::class, 'deleteReview'])->name('admin.fooditems.deleteReview');
            });

            Route::prefix('subadmins')->group(function () {
                //   Route::get('/', [SubAdminController::class, 'index'])->name('index');
                Route::match(array('GET','POST'),'/', [SubAdminController::class, 'index'])->name('admin.subadmins.list');
                // Route::post('/', [SubAdminController::class, 'index'])->name('admin.subadmins.list');
                Route::get('/activateordeactivate/{id?}', [SubAdminController::class, 'activateordeactivate'])->name('admin.subadmins.activateordeactivate');
                Route::get('delete/{id?}', [SubAdminController::class, 'delete'])->name('admin.subadmins.delete');
                Route::get('/add', [SubAdminController::class, 'ShowAddSubAdminForm'])->name('admin.subadmins.add');
                Route::get('view/{id?}', [SubAdminController::class, 'view'])->name('admin.subadmins.view');

                Route::get('/edit/{user}', [SubAdminController::class, 'edit'])->name('admin.subadmins.edit');
                Route::post('/postaddnew', [SubAdminController::class, 'SubmitNewSubAdminForm'])->name('admin.subadmins.postaddnew');
                Route::put('/postaddedit', [SubAdminController::class, 'SubmitEditSubAdminForm'])->name('admin.subadmins.postaddedit');
            });

            Route::prefix('setting')->group(function () {
                Route::get('list', [SettingController::class, 'index'])->name('admin.setting.list');
                Route::get('edit/{setting?}', [SettingController::class, 'edit'])->name('admin.setting.edit');
                Route::get('videoEdit/{setting?}', [SettingController::class, 'videoEdit'])->name('admin.videoEdit.edit');
                Route::put('update', [SettingController::class, 'update'])->name('admin.setting.update');
                Route::put('update_unifoinic', [SettingController::class, 'update_unifoinic'])->name('admin.setting.update_unifoinic');
                Route::put('videoUpdate', [SettingController::class, 'videoUpdate'])->name('admin.setting.videoUpdate');
            });

            Route::prefix('staticcontent')->group(function () {

                //  Route::get('/', [AdminStaticPage::class, 'index'])->name('index');
                Route::match(array('GET','POST'),'/', [AdminStaticPage::class, 'index'])->name('admin.staticpages.list');
                // Route::post('/', [AdminStaticPage::class, 'index'])->name('admin.staticpages.list');
                Route::match(array('GET','PUT'),'/add', [AdminStaticPage::class, 'add'])->name('admin.staticpages.add');
                // Route::put('/add', [AdminStaticPage::class, 'store'])->name('admin.staticpages.add');
                Route::get('/edit/{user}', [AdminStaticPage::class, 'edit'])->name('admin.staticpages.edit');
                Route::put('/edit', [AdminStaticPage::class, 'update'])->name('admin.staticpages.postedit');
                Route::get('delete/{id?}', [AdminStaticPage::class, 'delete'])->name('admin.staticpages.delete');
            });
            Route::prefix('homedesigncontent')->group(function () {

                Route::match(array('GET','POST'),'/', [AdminHomePageDesignStaticContent::class, 'index'])->name('admin.homedesigncontent.list');
                // Route::post('/', [AdminHomePageDesignStaticContent::class, 'index'])->name('admin.homedesigncontent.list');
                Route::get('/edit/{user}', [AdminHomePageDesignStaticContent::class, 'edit'])->name('admin.homedesigncontent.edit');

                Route::put('/edit', [AdminHomePageDesignStaticContent::class, 'update'])->name('admin.homedesigncontent.postedit');

                Route::match(array('GET','PUT'),'/add', [AdminHomePageDesignStaticContent::class, 'add'])->name('admin.homedesigncontent.add');
                // Route::put('/add', [AdminHomePageDesignStaticContent::class, 'store'])->name('admin.homedesigncontent.add');
            });

          

           
        });
    });
});
